# Stub package for OCPP

This is a PEP-561 compliant stub package for the [Python OCPP library](https://pypi.org/project/ocpp/).
# License

Any original work within is licensed under the [CC0](https://wiki.creativecommons.org/wiki/CC0).

This repo was forked from [a sample repo](https://github.com/ethanhs/stub-package) found via the official [description of PEP-561](https://peps.python.org/pep-0561/).
